@@ -79,6 +79,7 @@ module Network.Wai
       -- ** Response modifiers
     , responseToStream
     , mapResponseHeaders
+    , mapResponseStatus
       -- * Middleware composition
     , ifRequest
     , modifyResponse
@@ -239,6 +240,13 @@ mapResponseHeaders f (ResponseBuilder s h b) = ResponseBuilder s (f h) b
 mapResponseHeaders f (ResponseStream s h b) = ResponseStream s (f h) b
 mapResponseHeaders _ r@(ResponseRaw _ _) = r
 
+-- | Apply the provided function to the response status of the Response.
+mapResponseStatus :: (H.Status -> H.Status) -> Response -> Response
+mapResponseStatus f (ResponseFile s h b1 b2) = ResponseFile (f s) h b1 b2
+mapResponseStatus f (ResponseBuilder s h b) = ResponseBuilder (f s) h b
+mapResponseStatus f (ResponseStream s h b) = ResponseStream (f s) h b
+mapResponseStatus _ r@(ResponseRaw _ _) = r
+
 ----------------------------------------------------------------
 
 -- | The WAI application.
